(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='%s' *)
(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       131,          6]
NotebookDataLength[     13401,        540]
NotebookOptionsPosition[     10488,        439]
NotebookOutlinePosition[     10984,        460]
CellTagsIndexPosition[     10941,        457]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Econometrics", "Title"],

Cell["\<\
Hal Varian
January 1992\
\>", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Goodness of Fit", "Section"],

Cell["\<\
Let's see how to measure goodness-of-fit, using the Cobb-Douglas money metric \
utility function.  Recall that this function is given by:\
\>", "Text"],

Cell["m[p1_,p2_,x1_,x2_] := 2 p1^(1/2)p2^(1/2)x1^(1/2)x2^(1/2)", "Input"],

Cell[TextData[{
 "Let's generate some Cobb-Douglas demand data and perturb it by a random \
variable.  We'll fix income at 100 and ",
 StyleBox["p2",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " at 1, and let ",
 StyleBox["p1",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " range from 1 to 10."
}], "Text"],

Cell["\<\
x1Data=Table[N[100/(2 p1)],{p1,1,10}]
errorTerm=Table[Random[]/5,{p1,1,10}]
x1DataPerturbed=x1Data*(1+errorTerm)
x2Data=Table[100/2,{p1,1,10}]\
\>", "Input"],

Cell[TextData[{
 "We want to make sure that the budget constraint is satisfied by the \
perturbed data.  Hence we multiply the second demand by ",
 StyleBox["(1-errorTerm)",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ".  We check the budget constraint next, to make sure we've done it right."
}], "Text"],

Cell["\<\
x2DataPerturbed=x2Data*(1-errorTerm)
x1DataPerturbed*Table[p1,{p1,1,10}] + x2DataPerturbed\
\>", "Input"],

Cell["Now we can compute the goodness of fit measures.", "Text"],

Cell["\<\
Table[N[m[i,1,x1DataPerturbed[[i]],x2DataPerturbed[[i]]]],
 {i,1,10}]\
\>", "Input"],

Cell["\<\
Note how close the values are to full efficiency.  We can have quite large \
perturbations of the data, and still be pretty close to optimizing behavior.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Agricultural economics", "Section"],

Cell["\<\
Here we give a numerical example of the phenomenon described in the text.  We \
have a number of farmers who want to maximize profits\
\>", "Text"],

Cell["profit[p_,q_,Q_,K_,S_] := p Q K^(1/2)S^(1/2) - q K", "Input"],

Cell[CellGroupData[{

Cell["profit[p,q,Q,K,S]", "Input"],

Cell[OutputFormData["\<\
-(K*q) + K^(1/2)*p*Q*S^(1/2)\
\>", "\<\
-(K q) + Sqrt[K] p Q Sqrt[S]\
\>"], "Output"]
}, Open  ]],

Cell["Solve for the profit-maximizing demand and output:", "Text"],

Cell[CellGroupData[{

Cell["\<\
solution=Solve[D[profit[p,q,Q,K,S],K]==0,K][[1]]
K[p_,q_,Q_,S_] := Evaluate[K/.solution]
K[p,q,Q,S]
Y[p_,q_,Q_,S_] := Evaluate[
                  PowerExpand[Q K^(1/2)S^(1/2)/.solution]]
Y[p,q,Q,S]\
\>", "Input"],

Cell[OutputFormData["\<\
{K -> (p^2*Q^2*S)/(4*q^2)}\
\>", "\<\
       2  2
      p  Q  S
{K -> -------}
          2
       4 q\
\>"], "Output"],

Cell[OutputFormData["\<\
(p^2*Q^2*S)/(4*q^2)\
\>", "\<\
 2  2
p  Q  S
-------
    2
 4 q\
\>"], "Output"],

Cell[OutputFormData["\<\
(p*Q^2*S)/(2*q)\
\>", "\<\
   2
p Q  S
------
 2 q\
\>"], "Output"]
}, Open  ]],

Cell[TextData[{
 "(The ",
 StyleBox["PowerExpand",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " operator puts the answer into a simpler form.)"
}], "Text"],

Cell[TextData[{
 "Now we'll generate some data for farms with high-quality land ",
 StyleBox["(Q=10)",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " and for farms with low-quality land ",
 StyleBox["(Q=2)",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ".   First we'll generate some prices:  "
}], "Text"],

Cell["\<\
nObs=100;
outputPrice=Table[Random[],{i,1,nObs}];
inputPrice=Table[Random[],{i,1,nObs}];
sunnyDays=Table[Random[],{i,1,nObs}];\
\>", "Input"],

Cell["\<\
highData=Transpose[{Log[K[outputPrice,inputPrice,10,sunnyDays]],
          Log[Y[outputPrice,inputPrice,10,sunnyDays]]}];
lowData=Transpose[{Log[K[outputPrice,inputPrice,2,sunnyDays]],
          Log[Y[outputPrice,inputPrice,2,sunnyDays]]}];\
\>", "Input"],

Cell["Now we'll fit the data for each quality of land separately.", "Text"],

Cell[CellGroupData[{

Cell["\<\
Fit[highData,{1,logK},logK]
Fit[lowData,{1,logK},logK]\
\>", "Input"],

Cell[OutputFormData["\<\
1.643494422115747 + 0.5550052067058297*logK\
\>", "\<\
1.64349 + 0.555005 logK\
\>"], "Output"],

Cell[OutputFormData["\<\
0.2111114397889185 + 0.5550052067058291*logK\
\>", "\<\
0.211111 + 0.555005 logK\
\>"], "Output"]
}, Open  ]],

Cell[TextData[{
 "Notice that we get the same answer---something pretty close to the correct \
value of  ",
 StyleBox["0.5",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ".  But now let's put the data together and try the same operation."
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
allData=Join[highData,lowData];
Fit[allData,{1,logK},logK]\
\>", "Input"],

Cell[OutputFormData["\<\
0.83921329281461 + 0.6500026259425358*logK\
\>", "\<\
0.839213 + 0.650003 logK\
\>"], "Output"]
}, Open  ]],

Cell[TextData[{
 "Note the upward bias in the estimated parameter.  We can do a scatterplot \
to see what's happening.  The true production relationship is ",
 StyleBox["logY=logQ + logK/2",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", so we add this to the graph for ",
 StyleBox["Q=2",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " and ",
 StyleBox["Q=10",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "."
}], "Text"],

Cell["\<\
lowPlot=ListPlot[lowData,PlotStyle->AbsolutePointSize[3],
        Epilog->{Line[{{5,Log[2]+5/2},{-10.0,Log[2]-10/2}}],
                 Line[{{5,Log[10]+5/2},{-10.0,Log[10]-10/2}}]}]
highPlot=ListPlot[highData,PlotStyle->AbsolutePointSize[5],
Epilog->{Line[{{5,Log[10]+5/2},{-10.0,Log[10]-10/2}}],
Line[{{5,Log[2]+5/2},{-10.0,Log[2]-10/2}}]}]
Show[{highPlot,lowPlot},{lowPlot,highPlot}]\
\>", "Input"],

Cell["\<\
Each true production function fits the  data well, but when we put the two \
sets of data together, the fitted regression line will be too steep.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Estimating the factor demand functions", "Subsection"],

Cell["\<\
Let's see if we can get better estimates by estimating the factor demand \
function  rather than the production function.    First we solve for the \
factor demand when the parameters of the production function are unknown.  \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
profit[p_,q_,Q_,K_,S_] := p Q K^a S^b - q K
D[profit[p,q,Q,K,S],K]\
\>", "Input"],

Cell[OutputFormData["\<\
-q + a*K^(-1 + a)*p*Q*S^b\
\>", "\<\
        -1 + a      b
-q + a K       p Q S\
\>"], "Output"]
}, Open  ]],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " has difficulty solving this equation, since it wants to find all \
solutions,  not just the real solutions that we care about.  But if we solve \
it by hand, we find that\n             ",
 StyleBox["Log[k] = (1/(1-a)) log(q/p) + constant + error term",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "\n To run this regression we need a new variable, and we need to extract ",
 StyleBox["Log[K]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " from ",
 StyleBox["allData",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ".  To extract ",
 StyleBox["Log[K]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", we ",
 StyleBox["Transpose",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " the list of data and take the first list using ",
 StyleBox["Take[Transpose[allData,1]]]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ".  Then we join this with the new variable we need"
}], "Text"],

Cell["Remember, we have to have two copies of the prices...", "Text"],

Cell[CellGroupData[{

Cell["\<\
priceRatio=Join[Log[outputPrice/inputPrice],
                Log[outputPrice/inputPrice]];
newData=Transpose[{priceRatio,
        Take[Transpose[allData],1][[1]]}];
Fit[newData,{1,logPratio},logPratio]\
\>", "Input"],

Cell[OutputFormData["\<\
0.5699842184481958 + 2.001895091262409*logPratio\
\>", "\<\
0.569984 + 2.0019 logPratio\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["estimatedValueOfa= 1-(1/1.8993)", "Input"],

Cell[OutputFormData["\<\
0.4734902332438267\
\>", "\<\
0.47349\
\>"], "Output"]
}, Open  ]],

Cell["\<\
Note how this value is much closer to the true value of  0.5.  [By the way, \
all of these statements are statistical statements, so every now and then \
this won't be true.  Run through these calculations again if this happens to \
you...]\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Diewert Cost function", "Section"],

Cell["\<\
Here is the unit cost function for a special cast of the Diewert cost \
function.  We want to determine the shape of the isoquants as a function of \
the parameters.  The most interesting parameter is the curvature parameter \
\>", "Text"],

Cell["\<\
Clear[b]
c[w1_,w2_,b_] := w1 + w2 +  2 b Sqrt[w1 w2]\
\>", "Input"],

Cell["The conditional factor demands are", "Text"],

Cell[CellGroupData[{

Cell["\<\
h1[w1_,w2_,b_] := Evaluate[D[c[w1,w2,b],w1]]
h2[w1_,w2_,b_] := Evaluate[D[c[w1,w2,b],w2]]
{h1[w1,w2,b],h2[w1,w2,b]}\
\>", "Input"],

Cell[OutputFormData["\<\
{1 + (b*w2)/(w1*w2)^(1/2), 1 + (b*w1)/(w1*w2)^(1/2)}\
\>", "\<\
        b w2             b w1
{1 + -----------, 1 + -----------}
     Sqrt[w1 w2]      Sqrt[w1 w2]\
\>"], "Output"]
}, Open  ]],

Cell[TextData[{
 "Normalize ",
 StyleBox["w2=1",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " and plot",
 StyleBox[" (h1,h2)",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", letting ",
 StyleBox["w1",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " vary.  We'll let the parameter",
 StyleBox[" b",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " vary from ",
 StyleBox["b=1",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " to ",
 StyleBox["b=10",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "."
}], "Text"],

Cell["\<\
Do[
 ParametricPlot[{h1[w1,1,b],h2[w1,1,b]},{w1,0.1,200},
 PlotLabel->b,AspectRatio->Automatic,
 PlotRange->{{0,30},{0,30}}],
 {b,1,10}
 ]\
\>", "Input"],

Cell[TextData[{
 ">From these diagrams it is easy to see that increasing",
 StyleBox[" ",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "b will tend to make the isoquantsflatter."
}], "Text"]
}, Open  ]]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{707, 850},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
FrontEndVersion->"8.0 for Microsoft Windows (64-bit) (October 6, 2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[553, 21, 29, 0, 83, "Title"],
Cell[585, 23, 54, 3, 47, "Subsubtitle"],
Cell[CellGroupData[{
Cell[664, 30, 34, 0, 71, "Section"],
Cell[701, 32, 161, 3, 47, "Text"],
Cell[865, 37, 73, 0, 31, "Input"],
Cell[941, 39, 317, 11, 49, "Text"],
Cell[1261, 52, 167, 5, 82, "Input"],
Cell[1431, 59, 310, 7, 48, "Text"],
Cell[1744, 68, 115, 3, 48, "Input"],
Cell[1862, 73, 64, 0, 29, "Text"],
Cell[1929, 75, 94, 3, 48, "Input"],
Cell[2026, 80, 177, 3, 47, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2240, 88, 41, 0, 71, "Section"],
Cell[2284, 90, 157, 3, 47, "Text"],
Cell[2444, 95, 67, 0, 31, "Input"],
Cell[CellGroupData[{
Cell[2536, 99, 34, 0, 31, "Input"],
Cell[2573, 101, 110, 4, 35, "Output"]
}, Open  ]],
Cell[2698, 108, 66, 0, 29, "Text"],
Cell[CellGroupData[{
Cell[2789, 112, 222, 7, 116, "Input"],
Cell[3014, 121, 143, 8, 75, "Output"],
Cell[3160, 131, 105, 8, 75, "Output"],
Cell[3268, 141, 92, 7, 65, "Output"]
}, Open  ]],
Cell[3375, 151, 161, 6, 30, "Text"],
Cell[3539, 159, 314, 10, 48, "Text"],
Cell[3856, 171, 151, 5, 82, "Input"],
Cell[4010, 178, 265, 5, 82, "Input"],
Cell[4278, 185, 75, 0, 29, "Text"],
Cell[CellGroupData[{
Cell[4378, 189, 79, 3, 48, "Input"],
Cell[4460, 194, 120, 4, 35, "Output"],
Cell[4583, 200, 122, 4, 35, "Output"]
}, Open  ]],
Cell[4720, 207, 254, 7, 48, "Text"],
Cell[CellGroupData[{
Cell[4999, 218, 83, 3, 48, "Input"],
Cell[5085, 223, 120, 4, 35, "Output"]
}, Open  ]],
Cell[5220, 230, 435, 15, 48, "Text"],
Cell[5658, 247, 411, 8, 133, "Input"],
Cell[6072, 257, 169, 3, 47, "Text"],
Cell[CellGroupData[{
Cell[6266, 264, 60, 0, 36, "Subsection"],
Cell[6329, 266, 249, 4, 47, "Text"],
Cell[CellGroupData[{
Cell[6603, 274, 91, 3, 48, "Input"],
Cell[6697, 279, 121, 5, 45, "Output"]
}, Open  ]],
Cell[6833, 287, 970, 30, 122, "Text"],
Cell[7806, 319, 69, 0, 29, "Text"],
Cell[CellGroupData[{
Cell[7900, 323, 226, 6, 99, "Input"],
Cell[8129, 331, 129, 4, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8295, 340, 48, 0, 31, "Input"],
Cell[8346, 342, 79, 4, 35, "Output"]
}, Open  ]],
Cell[8440, 349, 264, 5, 47, "Text"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8753, 360, 40, 0, 71, "Section"],
Cell[8796, 362, 249, 4, 47, "Text"],
Cell[9048, 368, 77, 3, 48, "Input"],
Cell[9128, 373, 50, 0, 29, "Text"],
Cell[CellGroupData[{
Cell[9203, 377, 140, 4, 65, "Input"],
Cell[9346, 383, 204, 6, 55, "Output"]
}, Open  ]],
Cell[9565, 392, 532, 26, 30, "Text"],
Cell[10100, 420, 163, 7, 116, "Input"],
Cell[10266, 429, 194, 6, 30, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

